==> texlive-base_2017.20180305.orig.tar.xz: texlive-base-2017.20180305/texmf-dist/doc/latex/tikz-feynhand/README.md <==

The package Tikz-FeynHand https://ctan.org/pkg/tikz-feynhand let's you draw Feynman diagrams using TikZ.

It is a low-end modification of the package TikZ-Feynman at https://ctan.org/pkg/tikz-feynman,
one of whose principal advantages is the automatic generation of diagrams, for which it needs LuaTex.
FeynHand only provides the manual mode and hence runs in LaTex without any reference to LuaTex.

In addition it provides some NEW STYLES for vertices and propagators, 
alternative SHORTER KEYWORDS in addition to TikZ-Feynman's longer ones, 
some shortcut commands for QUICKLY CUSTOMIZING the diagrams' look,
and the new feature to put one propagator "ON TOP" of another.

It also includes a quick USER GUIDE for getting started,
with many examples and a 5-minute introduction to TikZ.



 FILES
-------

1. tikz-feynhand.sty              - the tex style file of the package
2. tikzlibraryfeynhand.code.tex   - code file
3. tikzfeynhand.keys.code.tex     - defines Tikz keys
4. tikz-feynhand.userguide.pdf    - a userguide for the package
5. tikz-feynhand.userguide.tex    - the tex source of the userguide
6. changes.txt                    - lists changes applied to Tikz-Feynman to obtain Tikz-FeynHand
7. shell_escape.jpg               - a TexWorks screenshot for the userguide
8. README.md                      - this file



LICENSE
-------

Copyright (C) 2018  Max Dohse
Copyright (C) 2016  Joshua Ellis

This whole package (code and documentation)
may be redistributed and/or modified under the terms of the
GNU General Public License as published by the Free Software Foundation, either
version 3 of the License, or (at your option) any later version.

This work has the LPPL maintenance status `maintained'.

The Current Maintainer of this work is Max Dohse.

This package is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

==> texlive-base_2024.20250309.orig.tar.xz: texlive-base-2024.20250309/texmf-dist/doc/latex/tikz-feynhand/README.md <==

The package Tikz-FeynHand https://ctan.org/pkg/tikz-feynhand let's you draw Feynman diagrams using TikZ.

It is a low-end modification of the package TikZ-Feynman at https://ctan.org/pkg/tikz-feynman,
one of whose principal advantages is the automatic generation of diagrams, for which it needs LuaTex.
FeynHand only provides the manual mode and hence runs in LaTex without any reference to LuaTex.

In addition it provides some NEW STYLES for vertices and propagators, 
alternative SHORTER KEYWORDS in addition to TikZ-Feynman's longer ones, 
some shortcut commands for QUICKLY CUSTOMIZING the diagrams' look,
and the new feature to put one propagator "ON TOP" of another.

It also includes a quick USER GUIDE for getting started,
with many examples and a 5-minute introduction to TikZ.



 FILES
-------

1. tikz-feynhand.sty              - the tex style file of the package
2. tikzlibraryfeynhand.code.tex   - code file
3. tikzfeynhand.keys.code.tex     - defines Tikz keys
4. tikz-feynhand.userguide.pdf    - a userguide for the package
5. tikz-feynhand.userguide.tex    - the tex source of the userguide
6. changes.txt                    - lists changes since last version
7. shell_escape.jpg               - a TexWorks screenshot for the userguide
8. README.md                      - this file



LICENSE
-------

Copyright (C) 2019  Max Dohse
Copyright (C) 2016  Joshua Ellis

This whole package (code and documentation)
may be redistributed and/or modified under the terms of the
GNU General Public License as published by the Free Software Foundation, either
version 3 of the License, or (at your option) any later version.

This work has the LPPL maintenance status `maintained'.

The Current Maintainer of this work is Max Dohse.

This package is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
